@@ -134,8 +134,8 @@ class dfile:
                                                    some attributes of datafile are not availables when
                                                    numpy is not present
                                                    
-        adata = None (default) : use the data provided in a list of string as data file content. This is to provdie
-                                 information directly in datafile format
+        adata = my_lines (default = None) : use the data provided in a list of strings (my_lines) as data file content. 
+                                            The content of my_lines must follow the datafile syntax.
         
     """
     def __init__(self, filename, debug = False, new=False, skip = True, use_numpy = numpy_ok, fast = False, adata = None):
